@@ -1,4 +1,4 @@
-/* Copyright IBM Corp. 2013, 2017 */
+/* Copyright IBM Corp. 2013, 2019 */
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -16,8 +16,7 @@ void print_break() {
 }
 
 void print_separator(int indent) {
-	printf("%*s===========================================" \
-	       "================================\n\n", indent, "");
+	printf("\n\n");
 }
 
 void print_header(int indent, int layer, const char* layer_name) {
@@ -38,7 +37,10 @@ const char *attr2char(enum qc_attr_id id) {
 	case qc_type: return "qc_type";
 	case qc_model_capacity: return "qc_model_capacity";
 	case qc_model: return "qc_model";
+	case qc_type_name: return "qc_type_name";
+	case qc_type_family: return "qc_type_family";
 	case qc_sequence_code: return "qc_sequence_code";
+	case qc_lic_identifier: return "qc_lic_identifier";
 	case qc_plant: return "qc_plant";
 	case qc_num_cpu_total: return "qc_num_cpu_total";
 	case qc_num_cpu_configured: return "qc_num_cpu_configured";
@@ -66,7 +68,7 @@ const char *attr2char(enum qc_attr_id id) {
 	case qc_ifl_weight_capping: return "qc_ifl_weight_capping";
 	case qc_cluster_name: return "qc_cluster_name";
 	case qc_control_program_id: return "qc_control_program_id";
-	case qc_hardlimit_consumption: return "qc_hardlimit_consumption";
+	case qc_limithard_consumption: return "qc_limithard_consumption";
 	case qc_prorated_core_time: return "qc_prorated_core_time";
 	case qc_cp_limithard_cap: return "qc_cp_limithard_cap";
 	case qc_cp_capacity_cap: return "qc_cp_capacity_cap";
@@ -74,7 +76,9 @@ const char *attr2char(enum qc_attr_id id) {
 	case qc_ifl_capacity_cap: return "qc_ifl_capacity_cap";
 	case qc_capping: return "qc_capping";
 	case qc_capping_num: return "qc_capping_num";
-	case qc_mobility_eligible: return "qc_mobility_eligible";
+	case qc_mobility_enabled: return "qc_mobility_enabled";
+	case qc_has_secure: return "qc_has_secure";
+	case qc_secure: return "qc_secure";
 	case qc_has_multiple_cpu_types: return "qc_has_multiple_cpu_types";
 	case qc_cp_dispatch_limithard: return "qc_cp_dispatch_limithard";
 	case qc_ifl_dispatch_limithard: return "qc_ifl_dispatch_limithard";
@@ -82,6 +86,26 @@ const char *attr2char(enum qc_attr_id id) {
 	case qc_ifl_dispatch_type: return "qc_ifl_dispatch_type";
 	case qc_cp_capped_capacity: return "qc_cp_capped_capacity";
 	case qc_ifl_capped_capacity: return "qc_ifl_capped_capacity";
+	case qc_num_cp_threads: return "qc_num_cp_threads";
+	case qc_num_ifl_threads: return "qc_num_ifl_threads";
+	case qc_num_core_total: return "qc_num_core_total";
+	case qc_num_core_configured: return "qc_num_core_configured";
+	case qc_num_core_standby: return "qc_num_core_standby";
+	case qc_num_core_reserved: return "qc_num_core_reserved";
+	case qc_num_core_dedicated: return "qc_num_core_dedicated";
+	case qc_num_core_shared: return "qc_num_core_shared";
+	case qc_ziip_absolute_capping: return "qc_ziip_absolute_capping";
+	case qc_ziip_capacity_cap: return "qc_ziip_capacity_cap";
+	case qc_ziip_capped_capacity: return "qc_ziip_capped_capacity";
+	case qc_ziip_dispatch_limithard: return "qc_ziip_dispatch_limithard";
+	case qc_ziip_dispatch_type: return "qc_ziip_dispatch_type";
+	case qc_ziip_limithard_cap: return "qc_ziip_limithard_cap";
+	case qc_ziip_weight_capping: return "qc_ziip_weight_capping";
+	case qc_num_ziip_dedicated: return "qc_num_ziip_dedicated";
+	case qc_num_ziip_shared: return "qc_num_ziip_shared";
+	case qc_num_ziip_total: return "qc_num_ziip_total";
+	case qc_num_ziip_threads: return "qc_num_ziip_threads";
+
 	default: break;
 	}
 
@@ -454,37 +478,44 @@ void print_cec_information(void *hdl, int layer, int indent) {
 	print_string_attr(hdl, qc_layer_category, "n/a", layer, indent);
 	print_int_attr(hdl, qc_layer_type_num, "n/a", layer, indent);
 	print_int_attr(hdl, qc_layer_category_num, "n/a", layer, indent);
-	print_string_attr(hdl, qc_layer_name, "O V", layer, indent);
+	print_string_attr(hdl, qc_layer_name, "F V", layer, indent);
 	print_string_attr(hdl, qc_manufacturer, "S V", layer, indent);
 	print_string_attr(hdl, qc_type, "S V", layer, indent);
+	print_string_attr(hdl, qc_type_name, "S  ", layer, indent);
+	print_int_attr(hdl, qc_type_family, "S  ", layer, indent);
 	print_string_attr(hdl, qc_model_capacity, "S  ", layer, indent);
 	print_string_attr(hdl, qc_model, "S  ", layer, indent);
 	print_string_attr(hdl, qc_sequence_code, "S V", layer, indent);
+	print_string_attr(hdl, qc_lic_identifier, "S  ", layer, indent);
 	print_string_attr(hdl, qc_plant, "S V", layer, indent);
 
 	print_break();
-	print_int_attr(hdl, qc_num_cpu_total, "S  ", layer, indent);
-	print_int_attr(hdl, qc_num_cpu_configured, "S  ", layer, indent);
-	print_int_attr(hdl, qc_num_cpu_standby, "S  ", layer, indent);
-	print_int_attr(hdl, qc_num_cpu_reserved, "S  ", layer, indent);
-	print_int_attr(hdl, qc_num_cpu_dedicated, " hV", layer, indent);
-	print_int_attr(hdl, qc_num_cpu_shared, " hV", layer, indent);
+	print_int_attr(hdl, qc_num_core_total, "S  ", layer, indent);
+	print_int_attr(hdl, qc_num_core_configured, "S  ", layer, indent);
+	print_int_attr(hdl, qc_num_core_standby, "S  ", layer, indent);
+	print_int_attr(hdl, qc_num_core_reserved, "S  ", layer, indent);
+	print_int_attr(hdl, qc_num_core_dedicated, " hV", layer, indent);
+	print_int_attr(hdl, qc_num_core_shared, " hV", layer, indent);
 
 	print_break();
 	print_int_attr(hdl, qc_num_cp_total, " HV", layer, indent);
 	print_int_attr(hdl, qc_num_cp_dedicated, " hV", layer, indent);
 	print_int_attr(hdl, qc_num_cp_shared, " hV", layer, indent);
-
-	print_break();
 	print_int_attr(hdl, qc_num_ifl_total, " HV", layer, indent);
 	print_int_attr(hdl, qc_num_ifl_dedicated, " hV", layer, indent);
 	print_int_attr(hdl, qc_num_ifl_shared, " hV", layer, indent);
+	print_int_attr(hdl, qc_num_ziip_total, " HV", layer, indent);
+	print_int_attr(hdl, qc_num_ziip_dedicated, " hV", layer, indent);
+	print_int_attr(hdl, qc_num_ziip_shared, " hV", layer, indent);
+
+	print_break();
+	print_int_attr(hdl, qc_num_cp_threads, "S  ", layer, indent);
+	print_int_attr(hdl, qc_num_ifl_threads, "S  ", layer, indent);
+	print_int_attr(hdl, qc_num_ziip_threads, "S  ", layer, indent);
 
 	print_break();
 	print_float_attr(hdl, qc_capability, "S  ", layer, indent);
 	print_float_attr(hdl, qc_secondary_capability, "S  ", layer, indent);
-
-	print_break();
 	print_int_attr(hdl, qc_capacity_adjustment_indication, "S  ", layer, indent);
 	print_int_attr(hdl, qc_capacity_change_reason, "S  ", layer, indent);
 
@@ -502,6 +533,7 @@ void print_lpar_group_information(void *hdl, int layer, int indent) {
 	print_string_attr(hdl, qc_layer_name, " hV", layer, indent);
 	print_int_attr(hdl, qc_cp_absolute_capping, " hV", layer, indent);
 	print_int_attr(hdl, qc_ifl_absolute_capping, " hV", layer, indent);
+	print_int_attr(hdl, qc_ziip_absolute_capping, " hV", layer, indent);
 
 	// check an attribute that only exists at a different layer
 	verify_nonexistence(hdl, qc_secondary_capability, layer);
@@ -521,30 +553,38 @@ void print_lpar_information(void *hdl, int layer, int indent) {
 	print_string_attr(hdl, qc_partition_char, "S  ", layer, indent);
 	print_int_attr(hdl, qc_partition_char_num, "S  ", layer, indent);
 	print_int_attr(hdl, qc_adjustment, "S  ", layer, indent);
+	print_int_attr(hdl, qc_has_secure, "F  ", layer, indent);
+	print_int_attr(hdl, qc_secure, "F  ", layer, indent);
 
 	print_break();
-	print_int_attr(hdl, qc_num_cpu_total, "S  ", layer, indent);
-	print_int_attr(hdl, qc_num_cpu_configured, "S  ", layer, indent);
-	print_int_attr(hdl, qc_num_cpu_standby, "S  ", layer, indent);
-	print_int_attr(hdl, qc_num_cpu_reserved, "S  ", layer, indent);
-	print_int_attr(hdl, qc_num_cpu_dedicated, "S  ", layer, indent);
-	print_int_attr(hdl, qc_num_cpu_shared, "S  ", layer, indent);
+	print_int_attr(hdl, qc_num_core_total, "S  ", layer, indent);
+	print_int_attr(hdl, qc_num_core_configured, "S  ", layer, indent);
+	print_int_attr(hdl, qc_num_core_standby, "S  ", layer, indent);
+	print_int_attr(hdl, qc_num_core_reserved, "S  ", layer, indent);
+	print_int_attr(hdl, qc_num_core_dedicated, "S  ", layer, indent);
+	print_int_attr(hdl, qc_num_core_shared, "S  ", layer, indent);
 
 	print_break();
 	print_int_attr(hdl, qc_num_cp_total, " HV", layer, indent);
 	print_int_attr(hdl, qc_num_cp_dedicated, " hV", layer, indent);
 	print_int_attr(hdl, qc_num_cp_shared, " hV", layer, indent);
-
-	print_break();
 	print_int_attr(hdl, qc_num_ifl_total, " HV", layer, indent);
 	print_int_attr(hdl, qc_num_ifl_dedicated, " hV", layer, indent);
 	print_int_attr(hdl, qc_num_ifl_shared, " hV", layer, indent);
+	print_int_attr(hdl, qc_num_ziip_total, " HV", layer, indent);
+	print_int_attr(hdl, qc_num_ziip_dedicated, " hV", layer, indent);
+	print_int_attr(hdl, qc_num_ziip_shared, " hV", layer, indent);
 
 	print_break();
+	print_int_attr(hdl, qc_num_cp_threads, "S  ", layer, indent);
+	print_int_attr(hdl, qc_num_ifl_threads, "S  ", layer, indent);
+	print_int_attr(hdl, qc_num_ziip_threads, "S  ", layer, indent);
 	print_int_attr(hdl, qc_cp_absolute_capping, " hV", layer, indent);
 	print_int_attr(hdl, qc_cp_weight_capping, " hV", layer, indent);
 	print_int_attr(hdl, qc_ifl_absolute_capping, " hV", layer, indent);
 	print_int_attr(hdl, qc_ifl_weight_capping, " hV", layer, indent);
+	print_int_attr(hdl, qc_ziip_absolute_capping, " hV", layer, indent);
+	print_int_attr(hdl, qc_ziip_weight_capping, " hV", layer, indent);
 
 	// check an attribute that only exists at a different layer
 	verify_nonexistence(hdl, qc_secondary_capability, layer);
@@ -561,26 +601,73 @@ void print_zvmhyp_information(void *hdl, int layer, int indent) {
 	print_string_attr(hdl, qc_cluster_name, "  V", layer, indent);
 	print_string_attr(hdl, qc_control_program_id, "S  ", layer, indent);
 	print_int_attr(hdl, qc_adjustment, "S  ", layer, indent);
-	print_int_attr(hdl, qc_hardlimit_consumption, "  V", layer, indent);
+	print_int_attr(hdl, qc_limithard_consumption, "  V", layer, indent);
 	print_int_attr(hdl, qc_prorated_core_time, "  V", layer, indent);
 
 	print_break();
-	print_int_attr(hdl, qc_num_cpu_total, "  V", layer, indent);
-	print_int_attr(hdl, qc_num_cpu_dedicated, "  V", layer, indent);
-	print_int_attr(hdl, qc_num_cpu_shared, "  V", layer, indent);
+	print_int_attr(hdl, qc_num_core_total, "  V", layer, indent);
+	print_int_attr(hdl, qc_num_core_dedicated, "  V", layer, indent);
+	print_int_attr(hdl, qc_num_core_shared, "  V", layer, indent);
+
+	print_break();
 	print_int_attr(hdl, qc_num_cp_total, "  V", layer, indent);
 	print_int_attr(hdl, qc_num_cp_dedicated, "  V", layer, indent);
 	print_int_attr(hdl, qc_num_cp_shared, "  V", layer, indent);
 	print_int_attr(hdl, qc_num_ifl_total, "  V", layer, indent);
 	print_int_attr(hdl, qc_num_ifl_dedicated, "  V", layer, indent);
 	print_int_attr(hdl, qc_num_ifl_shared, "  V", layer, indent);
+	print_int_attr(hdl, qc_num_ziip_total, "  V", layer, indent);
+	print_int_attr(hdl, qc_num_ziip_dedicated, "  V", layer, indent);
+	print_int_attr(hdl, qc_num_ziip_shared, "  V", layer, indent);
+
+	print_break();
+	print_int_attr(hdl, qc_num_cp_threads, "  V", layer, indent);
+	print_int_attr(hdl, qc_num_ifl_threads, "  V", layer, indent);
+	print_int_attr(hdl, qc_num_ziip_threads, "  V", layer, indent);
+
+	// check an attribute that only exists at a different layer
+	verify_nonexistence(hdl, qc_cp_absolute_capping, layer);
+}
+
+void print_zoshyp_information(void *hdl, int layer, int indent) {
+	print_header(indent, layer, "z/OS-hypervisor");
+	indent += 2;
+	print_string_attr(hdl, qc_layer_type, "n/a", layer, indent);
+	print_string_attr(hdl, qc_layer_category, "n/a", layer, indent);
+	print_int_attr(hdl, qc_layer_type_num, "n/a", layer, indent);
+	print_int_attr(hdl, qc_layer_category_num, "n/a", layer, indent);
+	print_string_attr(hdl, qc_layer_name, "  V", layer, indent);
+	print_string_attr(hdl, qc_cluster_name, "  V", layer, indent);
+	print_string_attr(hdl, qc_control_program_id, "S  ", layer, indent);
+	print_int_attr(hdl, qc_adjustment, "S  ", layer, indent);
+
+	print_break();
+	print_int_attr(hdl, qc_num_core_total, "  V", layer, indent);
+	print_int_attr(hdl, qc_num_core_dedicated, "  V", layer, indent);
+	print_int_attr(hdl, qc_num_core_shared, "  V", layer, indent);
+
+	print_break();
+	print_int_attr(hdl, qc_num_cp_total, "  V", layer, indent);
+	print_int_attr(hdl, qc_num_cp_dedicated, "  V", layer, indent);
+	print_int_attr(hdl, qc_num_cp_shared, "  V", layer, indent);
+	print_int_attr(hdl, qc_num_ziip_total, "  V", layer, indent);
+	print_int_attr(hdl, qc_num_ziip_dedicated, "  V", layer, indent);
+	print_int_attr(hdl, qc_num_ziip_shared, "  V", layer, indent);
+
+	print_break();
+	print_int_attr(hdl, qc_num_cp_threads, "  V", layer, indent);
+	print_int_attr(hdl, qc_num_ziip_threads, "  V", layer, indent);
 
 	// check an attribute that only exists at a different layer
 	verify_nonexistence(hdl, qc_cp_absolute_capping, layer);
 }
 
 void print_zvmpool_information(void *hdl, int layer, int indent) {
+#ifdef CONFIG_V1_COMPATIBILITY
 	print_header(indent, layer, "z/VM-CPU-pool");
+#else
+	print_header(indent, layer, "z/VM-resource-pool");
+#endif
 	indent += 2;
 	print_string_attr(hdl, qc_layer_type, "n/a", layer, indent);
 	print_string_attr(hdl, qc_layer_category, "n/a", layer, indent);
@@ -595,6 +682,74 @@ void print_zvmpool_information(void *hdl, int layer, int indent) {
 	print_int_attr(hdl, qc_ifl_limithard_cap, "  V", layer, indent);
 	print_int_attr(hdl, qc_ifl_capacity_cap, "  V", layer, indent);
 	print_int_attr(hdl, qc_ifl_capped_capacity, "  V", layer, indent);
+	print_int_attr(hdl, qc_ziip_limithard_cap, "  V", layer, indent);
+	print_int_attr(hdl, qc_ziip_capacity_cap, "  V", layer, indent);
+	print_int_attr(hdl, qc_ziip_capped_capacity, "  V", layer, indent);
+
+	// check an attribute that only exists at a different layer
+	verify_nonexistence(hdl, qc_cp_absolute_capping, layer);
+}
+
+void print_zosresgroup_information(void *hdl, int layer, int indent) {
+	print_header(indent, layer, "z/OS-tenant-resource-group");
+	indent += 2;
+	print_string_attr(hdl, qc_layer_type, "n/a", layer, indent);
+	print_string_attr(hdl, qc_layer_category, "n/a", layer, indent);
+	print_int_attr(hdl, qc_layer_type_num, "n/a", layer, indent);
+	print_int_attr(hdl, qc_layer_category_num, "n/a", layer, indent);
+	print_string_attr(hdl, qc_layer_name, "  V", layer, indent);
+
+	print_break();
+	print_int_attr(hdl, qc_cp_limithard_cap, "  V", layer, indent);
+	print_int_attr(hdl, qc_cp_capacity_cap, "  V", layer, indent);
+	print_int_attr(hdl, qc_cp_capped_capacity, "  V", layer, indent);
+	print_int_attr(hdl, qc_ziip_limithard_cap, "  V", layer, indent);
+	print_int_attr(hdl, qc_ziip_capacity_cap, "  V", layer, indent);
+	print_int_attr(hdl, qc_ziip_capped_capacity, "  V", layer, indent);
+
+	// check an attribute that only exists at a different layer
+	verify_nonexistence(hdl, qc_cp_absolute_capping, layer);
+}
+
+void print_zoszcxserver_information(void *hdl, int layer, int indent) {
+	print_header(indent, layer, "z/OS-zCX-Server");
+	indent += 2;
+	print_string_attr(hdl, qc_layer_type, "n/a", layer, indent);
+	print_string_attr(hdl, qc_layer_category, "n/a", layer, indent);
+	print_int_attr(hdl, qc_layer_type_num, "n/a", layer, indent);
+	print_int_attr(hdl, qc_layer_category_num, "n/a", layer, indent);
+	print_string_attr(hdl, qc_layer_name, "S V", layer, indent);
+	print_string_attr(hdl, qc_capping, " H ", layer, indent);
+	print_int_attr(hdl, qc_capping_num, " H ", layer, indent);
+	print_int_attr(hdl, qc_has_secure, "F  ", layer, indent);
+	print_int_attr(hdl, qc_secure, "F  ", layer, indent);
+
+	print_break();
+	print_int_attr(hdl, qc_num_cpu_total, "S V", layer, indent);
+	print_int_attr(hdl, qc_num_cpu_configured, "S  ", layer, indent);
+	print_int_attr(hdl, qc_num_cpu_standby, "S  ", layer, indent);
+	print_int_attr(hdl, qc_num_cpu_reserved, "S  ", layer, indent);
+	print_int_attr(hdl, qc_num_cpu_dedicated, " HV", layer, indent);
+	print_int_attr(hdl, qc_num_cpu_shared, " HV", layer, indent);
+
+	print_break();
+	print_int_attr(hdl, qc_num_cp_total, "  V", layer, indent);
+	print_int_attr(hdl, qc_num_cp_dedicated, "  V", layer, indent);
+	print_int_attr(hdl, qc_num_cp_shared, "  V", layer, indent);
+	print_int_attr(hdl, qc_num_ziip_total, "  V", layer, indent);
+	print_int_attr(hdl, qc_num_ziip_dedicated, "  V", layer, indent);
+	print_int_attr(hdl, qc_num_ziip_shared, "  V", layer, indent);
+
+	print_break();
+	print_int_attr(hdl, qc_cp_dispatch_type, "  V", layer, indent);
+	print_int_attr(hdl, qc_cp_dispatch_limithard, "  V", layer, indent);
+	print_int_attr(hdl, qc_cp_capped_capacity, "  V", layer, indent);
+	print_int_attr(hdl, qc_ziip_dispatch_type, "  V", layer, indent);
+	print_int_attr(hdl, qc_ziip_dispatch_limithard, "  V", layer, indent);
+	print_int_attr(hdl, qc_ziip_capped_capacity, "  V", layer, indent);
+
+	print_break();
+	print_int_attr(hdl, qc_has_multiple_cpu_types, "  V", layer, indent);
 
 	// check an attribute that only exists at a different layer
 	verify_nonexistence(hdl, qc_cp_absolute_capping, layer);
@@ -610,6 +765,9 @@ void print_zvmguest_information(void *hdl, int layer, int indent) {
 	print_string_attr(hdl, qc_layer_name, "S V", layer, indent);
 	print_string_attr(hdl, qc_capping, " H ", layer, indent);
 	print_int_attr(hdl, qc_capping_num, " H ", layer, indent);
+	print_int_attr(hdl, qc_mobility_enabled, "  V", layer, indent);
+	print_int_attr(hdl, qc_has_secure, "F  ", layer, indent);
+	print_int_attr(hdl, qc_secure, "F  ", layer, indent);
 
 	print_break();
 	print_int_attr(hdl, qc_num_cpu_total, "S V", layer, indent);
@@ -623,21 +781,26 @@ void print_zvmguest_information(void *hdl, int layer, int indent) {
 	print_int_attr(hdl, qc_num_cp_total, "  V", layer, indent);
 	print_int_attr(hdl, qc_num_cp_dedicated, "  V", layer, indent);
 	print_int_attr(hdl, qc_num_cp_shared, "  V", layer, indent);
-
-	print_break();
 	print_int_attr(hdl, qc_num_ifl_total, "  V", layer, indent);
 	print_int_attr(hdl, qc_num_ifl_dedicated, "  V", layer, indent);
 	print_int_attr(hdl, qc_num_ifl_shared, "  V", layer, indent);
+	print_int_attr(hdl, qc_num_ziip_total, "  V", layer, indent);
+	print_int_attr(hdl, qc_num_ziip_dedicated, "  V", layer, indent);
+	print_int_attr(hdl, qc_num_ziip_shared, "  V", layer, indent);
 
 	print_break();
-	print_int_attr(hdl, qc_mobility_eligible, "  V", layer, indent);
-	print_int_attr(hdl, qc_has_multiple_cpu_types, "  V", layer, indent);
 	print_int_attr(hdl, qc_cp_dispatch_type, "  V", layer, indent);
 	print_int_attr(hdl, qc_cp_dispatch_limithard, "  V", layer, indent);
 	print_int_attr(hdl, qc_cp_capped_capacity, "  V", layer, indent);
 	print_int_attr(hdl, qc_ifl_dispatch_type, "  V", layer, indent);
 	print_int_attr(hdl, qc_ifl_dispatch_limithard, "  V", layer, indent);
 	print_int_attr(hdl, qc_ifl_capped_capacity, "  V", layer, indent);
+	print_int_attr(hdl, qc_ziip_dispatch_type, "  V", layer, indent);
+	print_int_attr(hdl, qc_ziip_dispatch_limithard, "  V", layer, indent);
+	print_int_attr(hdl, qc_ziip_capped_capacity, "  V", layer, indent);
+
+	print_break();
+	print_int_attr(hdl, qc_has_multiple_cpu_types, "  V", layer, indent);
 
 	// check an attribute that only exists at a different layer
 	verify_nonexistence(hdl, qc_cp_absolute_capping, layer);
@@ -654,9 +817,11 @@ void print_kvmhyp_information(void *hdl, int layer, int indent) {
 	print_int_attr(hdl, qc_adjustment, "S  ", layer, indent);
 
 	print_break();
-	print_int_attr(hdl, qc_num_cpu_total, "  V", layer, indent);
-	print_int_attr(hdl, qc_num_cpu_dedicated, "SHV", layer, indent);
-	print_int_attr(hdl, qc_num_cpu_shared, "SHV", layer, indent);
+	print_int_attr(hdl, qc_num_core_total, "  V", layer, indent);
+	print_int_attr(hdl, qc_num_core_dedicated, "SHV", layer, indent);
+	print_int_attr(hdl, qc_num_core_shared, "SHV", layer, indent);
+
+	print_break();
 	print_int_attr(hdl, qc_num_cp_total, " HV", layer, indent);
 	print_int_attr(hdl, qc_num_cp_dedicated, " hV", layer, indent);
 	print_int_attr(hdl, qc_num_cp_shared, " hV", layer, indent);
@@ -678,6 +843,8 @@ void print_kvmguest_information(void *hdl, int layer, int indent) {
 	print_string_attr(hdl, qc_layer_name, "S  ", layer, indent);
 	print_string_attr(hdl, qc_layer_extended_name, "S  ", layer, indent);
 	print_string_attr(hdl, qc_layer_uuid, "S  ", layer, indent);
+	print_int_attr(hdl, qc_has_secure, "F  ", layer, indent);
+	print_int_attr(hdl, qc_secure, "F  ", layer, indent);
 
 	print_break();
 	print_int_attr(hdl, qc_num_cpu_total, "S  ", layer, indent);
@@ -686,9 +853,13 @@ void print_kvmguest_information(void *hdl, int layer, int indent) {
 	print_int_attr(hdl, qc_num_cpu_reserved, "S  ", layer, indent);
 	print_int_attr(hdl, qc_num_cpu_dedicated, "S  ", layer, indent);
 	print_int_attr(hdl, qc_num_cpu_shared, "S  ", layer, indent);
+
+	print_break();
 	print_int_attr(hdl, qc_num_ifl_total, "S  ", layer, indent);
 	print_int_attr(hdl, qc_num_ifl_dedicated, "S  ", layer, indent);
 	print_int_attr(hdl, qc_num_ifl_shared, "S  ", layer, indent);
+
+	print_break();
 	print_int_attr(hdl, qc_ifl_dispatch_type, "SHV", layer, indent);
 
 	// check an attribute that only exists at a different layer
@@ -701,17 +872,17 @@ int get_handle(void **hdl, int *layers, int quiet) {
 	*hdl = qc_open(&rc);
 	if (rc < 0) {
 		if (!quiet)
-			printf("Error: Could not open configuration, rc=%d\n", rc);
+			printf("Error: Could not open capacity data, rc=%d\n", rc);
 		return 1;
 	}
 	if (rc > 0) {
 		if (!quiet)
-			printf("Warning: Configuration could not be opened completely, rc=%d\n", rc);
+			printf("Warning: Capacity data inconsistent, try again later (rc=%d)\n", rc);
 		return 2;
 	}
 	if (!*hdl) {
 		if (!quiet)
-			printf("Error: Could not open configuration\n");
+			printf("Error: Capacity data returned invalid handle, rc=%d\n", rc);
 		return 3;
 	}
 	*layers = qc_get_num_layers(*hdl, &rc);
@@ -749,10 +920,9 @@ static void *run_test(int quiet, int fulltest) {
 	}
 	if (quiet)
 		goto out;
-	print_separator(indent);
+	print_break();
 	printf("We are running %i layer(s)\n", layers);
 	print_break();
-	print_separator(indent);
 
 	if (sanity_checks(hdl, layers))
 		goto out;
@@ -782,15 +952,24 @@ static void *run_test(int quiet, int fulltest) {
 		case QC_LAYER_TYPE_KVM_HYPERVISOR:
 			print_kvmhyp_information(hdl, i, indent);
 			break;
+		case QC_LAYER_TYPE_ZOS_HYPERVISOR:
+			print_zoshyp_information(hdl, i, indent);
+			break;
 		case QC_LAYER_TYPE_ZVM_CPU_POOL:
 			print_zvmpool_information(hdl, i, indent);
 			break;
+		case QC_LAYER_TYPE_ZOS_TENANT_RESOURCE_GROUP:
+			print_zosresgroup_information(hdl, i, indent);
+			break;
 		case QC_LAYER_TYPE_ZVM_GUEST:
 			print_zvmguest_information(hdl, i, indent);
 			break;
 		case QC_LAYER_TYPE_KVM_GUEST:
 			print_kvmguest_information(hdl, i, indent);
 			break;
+		case QC_LAYER_TYPE_ZOS_ZCX_SERVER:
+			print_zoszcxserver_information(hdl, i, indent);
+			break;
 		default:
 			printf("Error: Unhandled layer type '%d' at layer %i, no detailed "
 				"information available.\n\n", etype, i);
@@ -814,11 +993,10 @@ out:
 	setenv("QC_AUTODUMP", "0", 1);
 	if (!quiet) {
 		print_separator(indent);
-		if (!err_cnt)
-			printf("Done, no errors detected\n");
-		else
+		if (err_cnt) {
 			printf("%d error(s) detected\n", err_cnt);
-		print_break();
+			print_break();
+		}
 	}
 
 	return hdl;
